module Debate.Arguments.Science.TruncatedMeta exposing (..)

import Debate.Types exposing (..)


argumentTruncatedMeta : Argument
argumentTruncatedMeta =
    { argumentTitle = "Argument For Truncated Meta-Analysis"
    , propositionTitle = "Meta-analytic summations that include adequately powered studies to the exclusion of insufficiently powered studies will provide better causal estimates than meta-analytic summations that include both adequately powered studies and insufficiently powered studies."
    , propositionSummary = "Summary"
    , proofLink  = "https://www.umsu.de/trees/#(P~5Q),(P)%7C=(Q)"
    , definitionTable =
        [ { definiendum = "P"
          , definiens = "underpowered studies provide weaker causal estimates than adequately powered studies"
          }
        , { definiendum = "Q"
          , definiens = "meta-analytic summations that include adequately powered studies to the exclusion of insufficiently powered studies will provide better causal estimates than meta-analytic summations that include both adequately powered studies and insufficiently powered studies"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If underpowered studies provide weaker causal estimates than adequately powered studies, then meta-analytic summations that include adequately powered studies to the exclusion of insufficiently powered studies will provide better causal estimates than meta-analytic summations that include both adequately powered studies and insufficiently powered studies."
                  , notation = "(P→Q)"
                  }
                , { premise = "Underpowered studies provide weaker causal estimates than adequately powered studies."
                  , notation = "(P)"
                  }
                ]
          , conclusion = "Therefore, meta-analytic summations that include adequately powered studies to the exclusion of insufficiently powered studies will provide better causal estimates than meta-analytic summations that include both adequately powered studies and insufficiently powered studies."
          , conclusionNotation = "(∴Q)"
          }
        ]
    }